@@ -1,8 +1,8 @@
 #' @rdname prediction
 #' @export
-prediction.gee <- function(model, ...) {
+prediction.gee <- function(model, calculate_se = FALSE, ...) {
     
-    pred <- data.frame(fitted = predict(model, ...))
+    pred <- make_data_frame(fitted = predict(model, ...))
     pred[["se.fitted"]] <- NA_real_
     
     # obs-x-(ncol(data)+2) data frame
